﻿using SqlSugar;
using System;
using wms.util.Check;

namespace wms.sqlsugar.model.fj
{
    /// <summary>
    /// 库存流水数据历史表
    /// </summary>
    [Tenant("fj")]
    [SugarTable(nameof(Bill_InvflowHistory) + "_{year}{month}{day}", "任务表")]
    [SplitTable(SplitType.Month)]//按年分表 （自带分表支持 年、季、月、周、日）
    public partial class Bill_InvflowHistory
    {
        /// <summary>
        ///  ID
        /// </summary>
        [SugarColumn(ColumnName = "Id", IsPrimaryKey = true, ColumnDescription = "ID")]
        public virtual long Id { get; set; } = IdFactory.NewId();

        /// <summary>
        ///  备注
        /// </summary>
        [SugarColumn(ColumnName = "Memo", Length = 500, IsNullable = true, ColumnDataType = "nvarchar", DefaultValue = "", ColumnDescription = "备注")]
        public virtual string Memo { get; set; }

        /// <summary>
        ///  创建用户
        /// </summary>
        [SugarColumn(ColumnName = "AddWho", Length = 50, ColumnDataType = "nvarchar", DefaultValue = "", IsNullable = false, ColumnDescription = "创建用户")]
        public virtual string AddWho { get; set; } = "";

        /// <summary>
        ///  更新用户
        /// </summary>
        [SugarColumn(ColumnName = "EditWho", Length = 50, ColumnDataType = "nvarchar", DefaultValue = "", IsNullable = false, ColumnDescription = "更新用户")]
        public virtual string EditWho { get; set; } = "";

        /// <summary>
        ///  创建时间
        /// </summary>
        [SplitField]
        [SugarColumn(ColumnName = "AddTime", DefaultValue = "1900-1-1", IsNullable = false, ColumnDescription = "创建时间")]
        public virtual DateTime AddTime { get; set; } = DateTime.Now;

        /// <summary>
        /// 更新时间
        /// </summary>
        [SugarColumn(ColumnName = "EditTime", DefaultValue = "1900-1-1", IsNullable = false, ColumnDescription = "更新时间")]
        public virtual DateTime EditTime { get; set; } = DateTime.Now;

        /// <summary>
        ///  仓库ID
        /// </summary>
        [SugarColumn(ColumnDataType = "bigint", IsNullable = false)]
        public long WarehouseId { get; set; }

        /// <summary>
        ///  容器ID
        /// </summary>
        [SugarColumn(ColumnDataType = "bigint", IsNullable = false)]
        public long ContGrpId { get; set; }

        /// <summary>
        ///  容器编号
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string ContGrpBarCode { get; set; }

        /// <summary>
        /// 组盘类型(1物料盘 2空盘)
        /// </summary>
        [SugarColumn(ColumnDataType = "int", IsNullable = false)]
        public int ContGrpType { get; set; }

        /// <summary>
        /// BoxBarCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string BoxBarCode { get; set; }

        /// <summary>
        /// BomDocsNo
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string BomDocsNo { get; set; }

        /// <summary>
        /// BomMatId
        /// </summary>
        [SugarColumn(ColumnDataType = "bigint", IsNullable = false)]
        public long BomMatId { get; set; }

        /// <summary>
        /// BomMatCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string BomMatCode { get; set; }

        /// <summary>
        /// BomMatName
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 100, IsNullable = true)]
        public string BomMatName { get; set; }

        /// <summary>
        /// BomSetId
        /// </summary>
        [SugarColumn(ColumnDataType = "bigint", IsNullable = false)]
        public long BomSetId { get; set; }

        /// <summary>
        /// ExecStateCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string ExecStateCode { get; set; }

        /// <summary>
        /// ExecDocsNo
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string ExecDocsNo { get; set; }

        /// <summary>
        /// ExecDocsRowNo
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string ExecDocsRowNo { get; set; }

        /// <summary>
        /// ExecDocsTypeCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string ExecDocsTypeCode { get; set; }

        /// <summary>
        /// InvInOut
        /// </summary>
        [SugarColumn(ColumnDataType = "int", IsNullable = false)]
        public int InvInOut { get; set; }

        /// <summary>
        /// ExecWho
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string ExecWho { get; set; }

        /// <summary>
        /// ExecTime
        /// </summary>
        [SugarColumn(ColumnDataType = "datetime", IsNullable = false)]
        public DateTime ExecTime { get; set; }

        /// <summary>
        /// PutRow
        /// </summary>
        [SugarColumn(ColumnDataType = "int", IsNullable = false)]
        public int PutRow { get; set; }

        /// <summary>
        /// PutCol
        /// </summary>
        [SugarColumn(ColumnDataType = "int", IsNullable = false)]
        public int PutCol { get; set; }

        /// <summary>
        /// PutLayer
        /// </summary>
        [SugarColumn(ColumnDataType = "int", IsNullable = false)]
        public int PutLayer { get; set; }

        /// <summary>
        /// InvBarCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string InvBarCode { get; set; }

        /// <summary>
        /// InvStateCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string InvStateCode { get; set; }

        /// <summary>
        /// InDocsNo
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string InDocsNo { get; set; }

        /// <summary>
        /// InDocsRowNo
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string InDocsRowNo { get; set; }

        /// <summary>
        /// SuppCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string SuppCode { get; set; }

        /// <summary>
        /// SuppName
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string SuppName { get; set; }

        /// <summary>
        /// CustCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string CustCode { get; set; }

        /// <summary>
        /// CustName
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string CustName { get; set; }

        /// <summary>
        /// MatId
        /// </summary>
        [SugarColumn(ColumnDataType = "bigint", IsNullable = false)]
        public long MatId { get; set; }

        /// <summary>
        /// MatCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string MatCode { get; set; }

        /// <summary>
        /// MatName
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 100, IsNullable = true)]
        public string MatName { get; set; }

        /// <summary>
        /// TolWQty
        /// </summary>
        [SugarColumn(ColumnDataType = "decimal", Length = 18, IsNullable = false)]
        public decimal TolWQty { get; set; }

        /// <summary>
        /// NetWQty
        /// </summary>
        [SugarColumn(ColumnDataType = "decimal", Length = 18, IsNullable = false)]
        public decimal NetWQty { get; set; }

        /// <summary>
        /// TareWQty
        /// </summary>
        [SugarColumn(ColumnDataType = "decimal", Length = 18, IsNullable = false)]
        public decimal TareWQty { get; set; }

        /// <summary>
        /// LengthQty
        /// </summary>
        [SugarColumn(ColumnDataType = "decimal", Length = 18, IsNullable = false)]
        public decimal LengthQty { get; set; }

        /// <summary>
        /// CaQty
        /// </summary>
        [SugarColumn(ColumnDataType = "decimal", Length = 18, IsNullable = false)]
        public decimal CaQty { get; set; }

        /// <summary>
        /// SolderQty
        /// </summary>
        [SugarColumn(ColumnDataType = "decimal", Length = 18, IsNullable = false)]
        public decimal SolderQty { get; set; }

        /// <summary>
        /// ContUsageQty
        /// </summary>
        [SugarColumn(ColumnDataType = "int", IsNullable = false)]
        public int ContUsageQty { get; set; }

        /// <summary>
        /// BatchNo
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string BatchNo { get; set; }

        /// <summary>
        /// ProductTime
        /// </summary>
        [SugarColumn(ColumnDataType = "datetime", IsNullable = false)]
        public DateTime ProductTime { get; set; }

        /// <summary>
        /// OneInTime
        /// </summary>
        [SugarColumn(ColumnDataType = "datetime", IsNullable = false)]
        public DateTime OneInTime { get; set; }

        /// <summary>
        /// RodBarCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string RodBarCode { get; set; }

        /// <summary>
        /// HWBarCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string HWBarCode { get; set; }

        /// <summary>
        /// RFIDBarCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string RFIDBarCode { get; set; }

        /// <summary>
        /// CLBarCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string CLBarCode { get; set; }

        /// <summary>
        /// HWTypeCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string HWTypeCode { get; set; }

        /// <summary>
        /// BoilerNo
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string BoilerNo { get; set; }

        /// <summary>
        /// PackNo
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string PackNo { get; set; }

        /// <summary>
        /// BrandNo
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string BrandNo { get; set; }

        /// <summary>
        /// ExecStd
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string ExecStd { get; set; }

        /// <summary>
        /// LicenceCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string LicenceCode { get; set; }

        /// <summary>
        /// IsSurplus
        /// </summary>
        [SugarColumn(ColumnDataType = "bit", IsNullable = false)]
        public bool IsSurplus { get; set; }

        /// <summary>
        /// IsRework
        /// </summary>
        [SugarColumn(ColumnDataType = "bit", IsNullable = false)]
        public bool IsRework { get; set; }

        /// <summary>
        /// IsBlack
        /// </summary>
        [SugarColumn(ColumnDataType = "bit", IsNullable = false)]
        public bool IsBlack { get; set; }

        /// <summary>
        /// IsCore
        /// </summary>
        [SugarColumn(ColumnDataType = "bit", IsNullable = false)]
        public bool IsCore { get; set; }

        /// <summary>
        /// IsFast
        /// </summary>
        [SugarColumn(ColumnDataType = "bit", IsNullable = false)]
        public bool IsFast { get; set; }

        /// <summary>
        /// IsFail
        /// </summary>
        [SugarColumn(ColumnDataType = "bit", IsNullable = false)]
        public bool IsFail { get; set; }

        /// <summary>
        /// FailReason
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 200, IsNullable = true)]
        public string FailReason { get; set; }

        /// <summary>
        /// SilkTypeCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string SilkTypeCode { get; set; }

        /// <summary>
        /// Grade
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string Grade { get; set; }

        /// <summary>
        /// IsBack
        /// </summary>
        [SugarColumn(ColumnDataType = "bit", IsNullable = false)]
        public bool IsBack { get; set; }

        /// <summary>
        /// BackReason
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 200, IsNullable = true)]
        public string BackReason { get; set; }

        /// <summary>
        /// IsTorsChk
        /// </summary>
        [SugarColumn(ColumnDataType = "bit", IsNullable = false)]
        public bool IsTorsChk { get; set; }

        /// <summary>
        /// TorsChkQty
        /// </summary>
        [SugarColumn(ColumnDataType = "int", IsNullable = false)]
        public int TorsChkQty { get; set; }

        /// <summary>
        /// TorsChkTime
        /// </summary>
        [SugarColumn(ColumnDataType = "datetime", IsNullable = false)]
        public DateTime TorsChkTime { get; set; }

        /// <summary>
        /// TorsChkValue
        /// </summary>
        [SugarColumn(ColumnDataType = "decimal", Length = 18, IsNullable = true)]
        public decimal? TorsChkValue { get; set; }

        /// <summary>
        /// TorsChkMachCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string TorsChkMachCode { get; set; }

        /// <summary>
        /// ProcessDocsCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string ProcessDocsCode { get; set; }

        /// <summary>
        /// ProductMachCode
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string ProductMachCode { get; set; }

        /// <summary>
        /// ProductLineNo
        /// </summary>
        [SugarColumn(ColumnDataType = "nvarchar", Length = 50, IsNullable = true)]
        public string ProductLineNo { get; set; }

        /// <summary>
        /// 货物大小
        /// </summary>
        [SugarColumn(IsNullable = false)]
        public int Size { get; set; }
    }
}